@@ -77,7 +77,7 @@ import types
 from paste.wsgilib import catch_errors_app
 from paste.response import has_header, header_value, replace_header
 from paste.request import resolve_relative_url
-from paste.util.quoting import strip_html, html_quote, no_quote
+from paste.util.quoting import strip_html, html_quote, no_quote, comment_quote
 
 SERVER_NAME = 'WSGI Server'
 TEMPLATE = """\
@@ -199,23 +199,25 @@ class HTTPException(Exception):
         args = {'explanation': escfunc(self.explanation),
                 'detail': escfunc(self.detail),
                 'comment': comment_escfunc(self.comment)}
-        if HTTPException.template == self.template:
-            return template % args
-        for (k, v) in environ.items():
-            args[k] = escfunc(v)
-        if self.headers:
-            for (k, v) in self.headers:
-                args[k.lower()] = escfunc(v)
+        if HTTPException.template != self.template:
+            for (k, v) in environ.items():
+                args[k] = escfunc(v)
+            if self.headers:
+                for (k, v) in self.headers:
+                    args[k.lower()] = escfunc(v)
+        for key, value in args.items():
+            if isinstance(value, unicode):
+                args[key] = value.encode('utf8', 'xmlcharrefreplace')
         return template % args
 
     def plain(self, environ):
         """ text/plain representation of the exception """
-        body = self.make_body(environ, strip_html(self.template), no_quote)
+        body = self.make_body(environ, strip_html(self.template), no_quote, comment_quote)
         return ('%s %s\r\n%s\r\n' % (self.code, self.title, body))
 
     def html(self, environ):
         """ text/html representation of the exception """
-        body = self.make_body(environ, self.template, html_quote, no_quote)
+        body = self.make_body(environ, self.template, html_quote, comment_quote)
         return TEMPLATE % {
                    'title': self.title,
                    'code': self.code,
@@ -332,14 +334,14 @@ class _HTTPMove(HTTPRedirection):
 
     def relative_redirect(cls, dest_uri, environ, detail=None, headers=None, comment=None):
         """
-        Create a redirect object with the dest_uri, which may be relative, 
+        Create a redirect object with the dest_uri, which may be relative,
         considering it relative to the uri implied by the given environ.
         """
         location = resolve_relative_url(dest_uri, environ)
         headers = headers or []
         headers.append(('Location', location))
         return cls(detail=detail, headers=headers, comment=comment)
-    
+
     relative_redirect = classmethod(relative_redirect)
 
     def location(self):
@@ -603,15 +605,6 @@ class HTTPExceptionHandler(object):
     """
     catches exceptions and turns them into proper HTTP responses
 
-    Attributes:
-
-       ``warning_level``
-           This attribute determines for what exceptions a stack
-           trace is kept for lower level reporting; by default, it
-           only keeps stack trace for 5xx, HTTPServerError exceptions.
-           To keep a stack trace for 4xx, HTTPClientError exceptions,
-           set this to 400.
-
     This middleware catches any exceptions (which are subclasses of
     ``HTTPException``) and turns them into proper HTTP responses.
     Note if the headers have already been sent, the stack trace is
@@ -625,6 +618,10 @@ class HTTPExceptionHandler(object):
     def __init__(self, application, warning_level=None):
         assert not warning_level or ( warning_level > 99 and
                                       warning_level < 600)
+        if warning_level is not None:
+            import warnings
+            warnings.warn('The warning_level parameter is not used or supported',
+                          DeprecationWarning, 2)
         self.warning_level = warning_level or 500
         self.application = application
 
@@ -661,4 +658,3 @@ def make_middleware(app, global_conf=None, warning_level=None):
     return HTTPExceptionHandler(app, warning_level=warning_level)
 
 __all__.extend(['HTTPExceptionHandler', 'get_exception'])
-
