@@ -90,16 +90,21 @@ class Proxy(object):
         if environ.get('CONTENT_TYPE'):
             headers['content-type'] = environ['CONTENT_TYPE']
         if environ.get('CONTENT_LENGTH'):
-            headers['content-length'] = environ['CONTENT_LENGTH'] 
-            length = int(environ['CONTENT_LENGTH'])
-            body = environ['wsgi.input'].read(length)
+            if environ['CONTENT_LENGTH'] == '-1':
+                # This is a special case, where the content length is basically undetermined
+                body = environ['wsgi.input'].read(-1)
+                headers['content-length'] = str(len(body))
+            else:
+                headers['content-length'] = environ['CONTENT_LENGTH'] 
+                length = int(environ['CONTENT_LENGTH'])
+                body = environ['wsgi.input'].read(length)
         else:
             body = ''
             
         path_info = urllib.quote(environ['PATH_INFO'])
         if self.path:            
             request_path = path_info
-            if request_path[0] == '/':
+            if request_path and request_path[0] == '/':
                 request_path = request_path[1:]
                 
             path = urlparse.urljoin(self.path, request_path)
@@ -211,6 +216,8 @@ class TransparentProxy(object):
         if environ.get('CONTENT_LENGTH'):
             length = int(environ['CONTENT_LENGTH'])
             body = environ['wsgi.input'].read(length)
+            if length == -1:
+                environ['CONTENT_LENGTH'] = str(len(body))
         elif 'CONTENT_LENGTH' not in environ:
             body = ''
             length = 0
