@@ -55,7 +55,7 @@ class add_close(object):
             # We can't raise an error or anything at this stage
             print >> sys.stderr, (
                 "Error: app_iter.close() was not called when finishing "
-                "WSGI request.  finalization function %s not called"
+                "WSGI request. finalization function %s not called"
                 % self.close_func)
 
 class add_start_close(object):
@@ -94,7 +94,7 @@ class add_start_close(object):
             # We can't raise an error or anything at this stage
             print >> sys.stderr, (
                 "Error: app_iter.close() was not called when finishing "
-                "WSGI request.  finalization function %s not called"
+                "WSGI request. finalization function %s not called"
                 % self.close_func)
 
 class chained_app_iters(object):
@@ -139,7 +139,7 @@ class chained_app_iters(object):
             # We can't raise an error or anything at this stage
             print >> sys.stderr, (
                 "Error: app_iter.close() was not called when finishing "
-                "WSGI request.  finalization function %s not called"
+                "WSGI request. finalization function %s not called"
                 % self.close_func)
 
 class encode_unicode_app_iter(object):
@@ -227,7 +227,7 @@ def catch_errors_app(application, environ, start_response, error_callback_app,
         return error_callback_app(environ, start_response, sys.exc_info())
     if type(app_iter) in (list, tuple):
         # These won't produce exceptions
-        if ok_callback:
+        if ok_callback is not None:
             ok_callback()
         return app_iter
     else:
@@ -304,6 +304,8 @@ def raw_interactive(application, path='', raise_on_wsgi_error=False,
     if path:
         (_, _, path_info, query, fragment) = urlsplit(str(path))
         path_info = urllib.unquote(path_info)
+        # urlsplit returns unicode so coerce it back to str
+        path_info, query = str(path_info), str(query)
         basic_environ['PATH_INFO'] = path_info
         if query:
             basic_environ['QUERY_STRING'] = query
@@ -435,7 +437,7 @@ def capture_output(environ, start_response, application):
     Sends status and header, but *not* body.  Returns (status,
     headers, body).  Typically this is used like:
     
-    .. code-block:: Python
+    .. code-block:: python
 
         def dehtmlifying_middleware(application):
             def replacement_app(environ, start_response):
@@ -486,12 +488,13 @@ def intercept_output(environ, application, conditional=None,
 
     Typically this is used like:
     
-    .. code-block:: Python
+    .. code-block:: python
 
         def dehtmlifying_middleware(application):
             def replacement_app(environ, start_response):
                 status, headers, body = intercept_output(
                     environ, application)
+                start_response(status, headers)
                 content_type = header_value(headers, 'content-type')
                 if (not content_type
                     or not content_type.startswith('text/html')):
@@ -507,7 +510,7 @@ def intercept_output(environ, application, conditional=None,
     will be returned.  You must detect that in your code and return
     the app_iter, like:
     
-    .. code-block:: Python
+    .. code-block:: python
 
         def dehtmlifying_middleware(application):
             def replacement_app(environ, start_response):
@@ -517,6 +520,7 @@ def intercept_output(environ, application, conditional=None,
                     start_response)
                 if status is None:
                     return body
+                start_response(status, headers)
                 body = re.sub(r'<.*?>', '', body)
                 return [body]
             return replacement_app
@@ -530,7 +534,7 @@ def intercept_output(environ, application, conditional=None,
     def replacement_start_response(status, headers, exc_info=None):
         if conditional is not None and not conditional(status, headers):
             data.append(None)
-            return start_response(status, headers)
+            return start_response(status, headers, exc_info)
         if data:
             data[:] = []
         data.append(status)
